#################################################################################
# zur verwendung der funktion plotpref() benoetigt man
#################################################################################
#
# - das R package ggplot2 installiert und geladen
# - die unten angefuehrte funktion plotpref()
# - einen dataframe der folgendermassen aussieht:
#
#
#   objects  estimate   group
#   o1     1.06960101   male
#   o2     0.57712593   male
#   o3     0.13712880   male
#   o4     0.17624502   male
#   o5     0.13390101   male
#   o6     0.00000000   male
#   o1     1.01753291   female
#   o2     0.39847621   female
#   o3     0.14697167   female
#   o4     0.42146391   female
#   o5     0.03378679   female
#   o6     0.00000000   female
#   o1     1.01753291   nn
#   o2     0.39847621   nn
#   o3     0.14697167   nn
#   o4     0.42146391   nn
#   o5     0.03378679   nn
#   o6     0.00000000   nn
#
#   die variablennamen muessen "objects", "estimates" und
#   "group" heissen:
#
#   "objects" sind die namen der objekte
#
#   "estimate" sind die parameterschaetzer die man darstellen will, koennen
#      auch worths sein (achtung bei mehreren gruppen: baseline + gruppenparameter
#      zusammenzaehlen)
#
#   "group" sind levels der personenkovariaten
#      wenn es keine gibt dann z.b. "alle" oder " " in alle zeilen schreiben
#
# aufruf: plotpref(dfr)
#    dfr ist der oben beschriebene dataframe
#
#################################################################################
#    changes:
#    adjusted obj names (string width now adjusted)
#    black transparent dots possible
#################################################################################
#
# einige anmerkungen:
#
# manual unter http://had.co.nz/ggplot2/
#
# die beschriftung laesst sich aendern mit:
#    main...ueberschrift
#    xlab,ylab ... beschriftung der achsen
#    aufruf dann zum beispiel:
#         plotpref(dfr, main="Uebertitel", xlab="eine x-achse", ylab="zahlen")
#
# fuer schwarzweiss plots kann man statt der farbem andere plotsymbole verwenden
#    hierzu in der funktion colour=objects mit shape=objects ersetzen
#    (es gibt aber nur wenige plotsymbole)
#
# aussehen der punkte kann geaendert werden mit
#    - size (1 sehr klein)
#    - bei entfernen der zeile mit # comment 1 erhaelt man s/w punkte
#    - bei entfernen der zeile mit # comment 2 erhaelt man nur faerbige punkte
#
# schwarze beschriftung der punkte kann durch
#    - lschen von # in der zeile mit # comment 3 erhalten werden.
#
#################################################################################
plotpref<-function(x, main="Preferences", xlab="Groups", ylab="Estimate")
{
     x<-x[order(x$group,-x$estimate),]
     group<-factor(x$group, ordered=TRUE)
     tab<-table(group)
     adj<-1/nchar(as.character(x$objects))
     hadj0<-rep(c(0,1),ceiling(tab[1]/2))
     hadj1<-ifelse(hadj0==0,-1,1)
     hadj<-adj*hadj1+hadj0
     x<-cbind(x,hadj)
     p<-qplot(group, estimate,
                colour=objects, size=4, # comment 1
                data=x, main=main, xlab=xlab, ylab=ylab)
     p$legend.position="none"
     psize<-geom_point(size=4,colour=alpha('black',0.2)) # comment 2
     ann<-geom_text(aes(x=group,y=estimate,label=objects
                # ,colour=NULL # comment 3
                ), hjust=hadj,size=4)
     print(p+psize+ann)
}

# beispiel:

estimate<-c(0,0.4,-0.5,0.4,0.1,0.0)
group<-c(rep("1",3),rep("2",3))
objects<-rep(LETTERS[1:3],2)
x<-data.frame(estimate,objects,group)

library(ggplot2)
plotpref(x)